@@ -87,14 +87,19 @@ class BaseHandler(RequestHandler):
             self.set_cors_header()
 
         if status_code == 404:
-            logging.error("HTTP 404: URL Not Found")
             return self.write_failed(code=status_code, msg="Not Found", name="HTTP 404")
         elif status_code == 405:
-            logging.error("HTTP 405: Method/URL Not Allowed")
             return self.write_failed(code=status_code, msg="HTTP 405: Method/URL Not Allowed", name="HTTP 405")
         elif status_code == 500:
-            logging.error(format_exc())
+            import sys
+            typ, value, tb = sys.exc_info()
+            logging.error("Uncaught exception %s\n%r", self._request_summary(), self.request, exc_info=(typ, value, tb))
+
             error = kwargs["exc_info"][1]
+            # 把除跨域异常外所有用raise抛出的内置异常类型，都转为200返回，内部保留500异常log
+            if isinstance(error, errors.ApiError) and error.code != errors.ErrorCorsUri.code:
+                self.set_status(200, "HTTP STSTUS 200")
+
             logging.error("异常时间：" + self.utils.int_to_date_string(self.utils.now(), "%Y-%m-%d %H:%M:%S"))
             if not hasattr(error, "message"):
                 message = error.args[0] if error.args else "未知错误"
@@ -102,6 +107,8 @@ class BaseHandler(RequestHandler):
             else:
                 logging.error("异常码：" + str(error.code))
                 logging.error("异常信息：" + error.message)
+
+            logging.error("参数:" + (json.dumps(self.params) if hasattr(self, "params") else "无"))
             if not hasattr(error, "code_name") or not hasattr(error, "code"):
                 return self.write_failed()
             else:
@@ -113,18 +120,17 @@ class BaseHandler(RequestHandler):
         request_time = 1000.0 * self.request.request_time()
         is_slow_request = request_time > int(self.application.app_config["wsgi"].get("slow_request_time", 1000))
         p = self.params if hasattr(self, "params") else {}
-        if self.application.app_config.get("logging_config", {}).get("level", "debug") != "debug":
-            if is_slow_request:
-                logging.warning("%d %s %.2fms", self.get_status(), self._request_summary(), request_time)
+        if is_slow_request:
+            logging.warning("%d %s %.2fms", self.get_status(), self._request_summary(), request_time)
 
-        if hasattr(self, "graylog"):
+        if hasattr(self, "graylog") and self.graylog:
             if self.application.app_config["graylog_config"].get("mode", 0) or is_slow_request:
                 self.graylog.from_server(short_message="OK", code=0, host=self.request.host, request_time=int(request_time), remote_ip=self.request.remote_ip,
                                          uri=self.request.path, params=p, method=self.request.method)
         return self.write({"code": 0, "msg": "OK", "data": get_return(self, data or {})})
 
     def write_failed(self, code=1, msg="Error. unknown error", name="HTTP 500"):
-        if hasattr(self, "graylog"):
+        if hasattr(self, "graylog") and self.graylog:
             p = self.params if hasattr(self, "params") else {}
             self.graylog.from_server(short_message=msg, code=code, track=format_exc()[-500:], host=self.request.host, header=self.request.headers._dict,
                                      remote_ip=self.request.remote_ip, uri=self.request.path, params=p, method=self.request.method)
